@@ -1,59 +1,59 @@
 $VAR1 = {
-          'size' => '16',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'news' => {
-                      'captcha' => 3,
-                      'messages' => '5',
-                      'right' => 5
-                    },
-          'files' => {
-                       'group' => 'lze',
-                       'owner' => 'lze',
-                       'chmod' => '0755'
-                     },
-          'version' => '1.03',
-          'admin' => {
-                       'password' => 'testpass'
-                     },
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'version' => '1.04',
+          'defaultAction' => 'ShowDatabases',
+          'mod' => 'n',
+          'language' => 'en',
           'uploads' => {
+                         'path' => '/var/www/htdocs//download',
                          'enabled' => 1,
                          'right' => 2,
                          'maxlength' => '2100000000000000',
-                         'path' => '/var/www/htdocs//download',
                          'chmod' => 438
                        },
+          'files' => {
+                       'owner' => 'lze',
+                       'group' => 'lze',
+                       'chmod' => '0755'
+                     },
           'floodtime' => 10,
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'mod' => 'n',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'language' => 'en',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
           'saveTranslate' => '0',
-          'htmlright' => '2',
-          'defaultAction' => 'ShowDatabases',
+          'news' => {
+                      'right' => 5,
+                      'messages' => '5',
+                      'captcha' => 3
+                    },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'tree' => {
+                      'links' => '/var/www/cgi-bin/config/links.pl',
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
+                    },
+          'size' => '16',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'database' => {
+                          'CurrentPass' => '',
+                          'CurrentHost' => 'localhost',
                           'password' => '',
                           'CurrentDb' => 'MySQLAdmin',
+                          'CurrentUser' => 'root',
                           'host' => 'localhost',
                           'name' => 'MySQLAdmin',
-                          'CurrentUser' => 'root',
-                          'CurrentPass' => '',
-                          'user' => 'root',
-                          'CurrentHost' => 'localhost'
+                          'user' => 'root'
                         },
-          'tree' => {
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
-                      'links' => '/var/www/cgi-bin/config/links.pl'
-                    },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'htmlright' => '2',
+          'admin' => {
+                       'password' => 'testpass'
+                     },
           'cgi' => {
-                     'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'cookiePath' => '/',
-                     'serverName' => 'http://localhost',
                      'bin' => '/var/www/cgi-bin',
-                     'style' => 'mysql',
-                     'title' => 'MySQL::Admin'
+                     'cookiePath' => '/',
+                     'title' => 'MySQL::Admin',
+                     'expires' => '+1y',
+                     'serverName' => 'http://localhost',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'style' => 'mysql'
                    }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
