@@ -168,11 +168,11 @@ index.html
 
 </pre>
 
-Under mod_perl the whole page load in 0.1 seconds.
-
 I write a whole Documentation soon.No feedback so I'm not in rush.
 
-Look at http://lindnerei.sourceforge.net or http://lindnerei.de further Details.
+Look at http://lindnerei.sourceforge.net or http://lindnerei.de for further Details.
+ 
+=cut
  
 */
 
@@ -361,7 +361,6 @@ function submitForm(node, tabId, tabTitle, bHistory, method, uri) {
 var http_request = false;
 var oldpage = 0;
 
-
 //requestURI('cgi-bin/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
 /*
 =head2 requestURI(url, id, txt, bHistory, formData, method, bWaid)
