@@ -201,6 +201,14 @@ sub highlightCode {
     return "[Formatstring$currentstring/]";
 }
 
+=head2 formatString
+
+use Syntax::Highlight::Engine::Kate; to higlight source_code
+
+see highlightCode
+
+=cut
+
 sub formatString {
     my ($string, $lang) = @_;
     my $rplc;
